@@ -55,7 +55,7 @@ class AddAggregateHost(command.ShowOne):
     _description = _("Add host to aggregate")
 
     def get_parser(self, prog_name):
-        parser = super(AddAggregateHost, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'aggregate',
             metavar='<aggregate>',
@@ -88,7 +88,7 @@ class CreateAggregate(command.ShowOne):
     _description = _("Create a new aggregate")
 
     def get_parser(self, prog_name):
-        parser = super(CreateAggregate, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             "name", metavar="<name>", help=_("New aggregate name")
         )
@@ -136,7 +136,7 @@ class DeleteAggregate(command.Command):
     _description = _("Delete existing aggregate(s)")
 
     def get_parser(self, prog_name):
-        parser = super(DeleteAggregate, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'aggregate',
             metavar='<aggregate>',
@@ -178,7 +178,7 @@ class ListAggregate(command.Lister):
     _description = _("List all aggregates")
 
     def get_parser(self, prog_name):
-        parser = super(ListAggregate, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             '--long',
             action='store_true',
@@ -192,47 +192,53 @@ class ListAggregate(command.Lister):
 
         aggregates = list(compute_client.aggregates())
 
+        if sdk_utils.supports_microversion(compute_client, '2.41'):
+            column_headers = ("ID", "UUID")
+            columns = ("id", "uuid")
+        else:
+            column_headers = ("ID",)
+            columns = ("id",)
+
+        column_headers += (
+            "Name",
+            "Availability Zone",
+        )
+        columns += (
+            "name",
+            "availability_zone",
+        )
+
         if parsed_args.long:
             # Remove availability_zone from metadata because Nova doesn't
             for aggregate in aggregates:
                 if 'availability_zone' in aggregate.metadata:
                     aggregate.metadata.pop('availability_zone')
-            # This is the easiest way to change column headers
-            column_headers = (
-                "ID",
-                "Name",
-                "Availability Zone",
+
+            column_headers += (
                 "Properties",
                 "Hosts",
             )
-            columns = (
-                "ID",
-                "Name",
-                "Availability Zone",
-                "Metadata",
-                "Hosts",
-            )
-        else:
-            column_headers = columns = (
-                "ID",
-                "Name",
-                "Availability Zone",
+            columns += (
+                "metadata",
+                "hosts",
             )
 
-        data = (
-            utils.get_item_properties(
-                s, columns, formatters=_aggregate_formatters
-            )
-            for s in aggregates
+        return (
+            column_headers,
+            (
+                utils.get_item_properties(
+                    s, columns, formatters=_aggregate_formatters
+                )
+                for s in aggregates
+            ),
         )
-        return (column_headers, data)
 
 
 class RemoveAggregateHost(command.ShowOne):
     _description = _("Remove host from aggregate")
 
     def get_parser(self, prog_name):
-        parser = super(RemoveAggregateHost, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'aggregate',
             metavar='<aggregate>',
@@ -265,7 +271,7 @@ class SetAggregate(command.Command):
     _description = _("Set aggregate properties")
 
     def get_parser(self, prog_name):
-        parser = super(SetAggregate, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'aggregate',
             metavar='<aggregate>',
@@ -337,7 +343,7 @@ class ShowAggregate(command.ShowOne):
     _description = _("Display aggregate details")
 
     def get_parser(self, prog_name):
-        parser = super(ShowAggregate, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'aggregate',
             metavar='<aggregate>',
@@ -366,7 +372,7 @@ class UnsetAggregate(command.Command):
     _description = _("Unset aggregate properties")
 
     def get_parser(self, prog_name):
-        parser = super(UnsetAggregate, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             "aggregate",
             metavar="<aggregate>",
@@ -403,7 +409,7 @@ class CacheImageForAggregate(command.Command):
     # not be anything to return.
 
     def get_parser(self, prog_name):
-        parser = super(CacheImageForAggregate, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'aggregate',
             metavar='<aggregate>',
