@@ -20,7 +20,6 @@ import logging
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
-import six
 
 from openstackclient.i18n import _
 from openstackclient.identity import common
@@ -36,11 +35,47 @@ def get_service_name(service):
         return ''
 
 
-class CreateEndpoint(command.ShowOne):
-    """Create new endpoint"""
+class AddProjectToEndpoint(command.Command):
+    _description = _("Associate a project to an endpoint")
 
     def get_parser(self, prog_name):
-        parser = super(CreateEndpoint, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            'endpoint',
+            metavar='<endpoint>',
+            help=_(
+                'Endpoint to associate with ' 'specified project (name or ID)'
+            ),
+        )
+        parser.add_argument(
+            'project',
+            metavar='<project>',
+            help=_(
+                'Project to associate with ' 'specified endpoint name or ID)'
+            ),
+        )
+        common.add_project_domain_option_to_parser(parser)
+        return parser
+
+    def take_action(self, parsed_args):
+        client = self.app.client_manager.identity
+
+        endpoint = utils.find_resource(client.endpoints, parsed_args.endpoint)
+
+        project = common.find_project(
+            client, parsed_args.project, parsed_args.project_domain
+        )
+
+        client.endpoint_filter.add_endpoint_to_project(
+            project=project.id, endpoint=endpoint.id
+        )
+
+
+class CreateEndpoint(command.ShowOne):
+    _description = _("Create new endpoint")
+
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'service',
             metavar='<service>',
@@ -87,7 +122,7 @@ class CreateEndpoint(command.ShowOne):
             url=parsed_args.url,
             interface=parsed_args.interface,
             region=parsed_args.region,
-            enabled=parsed_args.enabled
+            enabled=parsed_args.enabled,
         )
 
         info = {}
@@ -95,14 +130,14 @@ class CreateEndpoint(command.ShowOne):
         info.update(endpoint._info)
         info['service_name'] = get_service_name(service)
         info['service_type'] = service.type
-        return zip(*sorted(six.iteritems(info)))
+        return zip(*sorted(info.items()))
 
 
 class DeleteEndpoint(command.Command):
-    """Delete endpoint(s)"""
+    _description = _("Delete endpoint(s)")
 
     def get_parser(self, prog_name):
-        parser = super(DeleteEndpoint, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'endpoint',
             metavar='<endpoint-id>',
@@ -117,30 +152,36 @@ class DeleteEndpoint(command.Command):
         for i in parsed_args.endpoint:
             try:
                 endpoint_id = utils.find_resource(
-                    identity_client.endpoints, i).id
+                    identity_client.endpoints, i
+                ).id
                 identity_client.endpoints.delete(endpoint_id)
             except Exception as e:
                 result += 1
-                LOG.error(_("Failed to delete endpoint with "
-                          "ID '%(endpoint)s': %(e)s")
-                          % {'endpoint': i, 'e': e})
+                LOG.error(
+                    _(
+                        "Failed to delete endpoint with "
+                        "ID '%(endpoint)s': %(e)s"
+                    ),
+                    {'endpoint': i, 'e': e},
+                )
 
         if result > 0:
             total = len(parsed_args.endpoint)
-            msg = (_("%(result)s of %(total)s endpoints failed "
-                   "to delete.") % {'result': result, 'total': total})
+            msg = _(
+                "%(result)s of %(total)s endpoints failed " "to delete."
+            ) % {'result': result, 'total': total}
             raise exceptions.CommandError(msg)
 
 
 class ListEndpoint(command.Lister):
-    """List endpoints"""
+    _description = _("List endpoints")
 
     def get_parser(self, prog_name):
-        parser = super(ListEndpoint, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             '--service',
             metavar='<service>',
-            help=_('Filter by service (name or ID)'),
+            help=_('Filter by service (type, name or ID)'),
         )
         parser.add_argument(
             '--interface',
@@ -153,38 +194,134 @@ class ListEndpoint(command.Lister):
             metavar='<region-id>',
             help=_('Filter by region ID'),
         )
+        list_group = parser.add_mutually_exclusive_group()
+        list_group.add_argument(
+            '--endpoint',
+            metavar='<endpoint-group>',
+            help=_('Endpoint to list filters'),
+        )
+        list_group.add_argument(
+            '--project',
+            metavar='<project>',
+            help=_('Project to list filters (name or ID)'),
+        )
+        common.add_project_domain_option_to_parser(parser)
         return parser
 
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
-        columns = ('ID', 'Region', 'Service Name', 'Service Type',
-                   'Enabled', 'Interface', 'URL')
-        kwargs = {}
-        if parsed_args.service:
-            service = common.find_service(identity_client, parsed_args.service)
-            kwargs['service'] = service.id
-        if parsed_args.interface:
-            kwargs['interface'] = parsed_args.interface
-        if parsed_args.region:
-            kwargs['region'] = parsed_args.region
-        data = identity_client.endpoints.list(**kwargs)
 
-        for ep in data:
-            service = common.find_service(identity_client, ep.service_id)
-            ep.service_name = get_service_name(service)
-            ep.service_type = service.type
-        return (columns,
-                (utils.get_item_properties(
-                    s, columns,
+        endpoint = None
+        if parsed_args.endpoint:
+            endpoint = utils.find_resource(
+                identity_client.endpoints, parsed_args.endpoint
+            )
+        project = None
+        if parsed_args.project:
+            project = common.find_project(
+                identity_client,
+                parsed_args.project,
+                parsed_args.project_domain,
+            )
+
+        if endpoint:
+            columns = ('ID', 'Name')
+            data = identity_client.endpoint_filter.list_projects_for_endpoint(
+                endpoint=endpoint.id
+            )
+        else:
+            columns = (
+                'ID',
+                'Region',
+                'Service Name',
+                'Service Type',
+                'Enabled',
+                'Interface',
+                'URL',
+            )
+            kwargs = {}
+            if parsed_args.service:
+                service = common.find_service(
+                    identity_client, parsed_args.service
+                )
+                kwargs['service'] = service.id
+            if parsed_args.interface:
+                kwargs['interface'] = parsed_args.interface
+            if parsed_args.region:
+                kwargs['region'] = parsed_args.region
+
+            if project:
+                data = (
+                    identity_client.endpoint_filter.list_endpoints_for_project(
+                        project=project.id
+                    )
+                )
+            else:
+                data = identity_client.endpoints.list(**kwargs)
+
+            service_list = identity_client.services.list()
+
+            for ep in data:
+                service = common.find_service_in_list(
+                    service_list, ep.service_id
+                )
+                ep.service_name = get_service_name(service)
+                ep.service_type = service.type
+
+        return (
+            columns,
+            (
+                utils.get_item_properties(
+                    s,
+                    columns,
                     formatters={},
-                ) for s in data))
+                )
+                for s in data
+            ),
+        )
+
+
+class RemoveProjectFromEndpoint(command.Command):
+    _description = _("Dissociate a project from an endpoint")
+
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            'endpoint',
+            metavar='<endpoint>',
+            help=_(
+                'Endpoint to dissociate from ' 'specified project (name or ID)'
+            ),
+        )
+        parser.add_argument(
+            'project',
+            metavar='<project>',
+            help=_(
+                'Project to dissociate from ' 'specified endpoint name or ID)'
+            ),
+        )
+        common.add_project_domain_option_to_parser(parser)
+        return parser
+
+    def take_action(self, parsed_args):
+        client = self.app.client_manager.identity
+
+        endpoint = utils.find_resource(client.endpoints, parsed_args.endpoint)
+
+        project = common.find_project(
+            client, parsed_args.project, parsed_args.project_domain
+        )
+
+        client.endpoint_filter.delete_endpoint_from_project(
+            project=project.id, endpoint=endpoint.id
+        )
 
 
 class SetEndpoint(command.Command):
-    """Set endpoint properties"""
+    _description = _("Set endpoint properties")
 
     def get_parser(self, prog_name):
-        parser = super(SetEndpoint, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'endpoint',
             metavar='<endpoint-id>',
@@ -228,8 +365,9 @@ class SetEndpoint(command.Command):
 
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
-        endpoint = utils.find_resource(identity_client.endpoints,
-                                       parsed_args.endpoint)
+        endpoint = utils.find_resource(
+            identity_client.endpoints, parsed_args.endpoint
+        )
 
         service_id = None
         if parsed_args.service:
@@ -247,27 +385,30 @@ class SetEndpoint(command.Command):
             url=parsed_args.url,
             interface=parsed_args.interface,
             region=parsed_args.region,
-            enabled=enabled
+            enabled=enabled,
         )
 
 
 class ShowEndpoint(command.ShowOne):
-    """Display endpoint details"""
+    _description = _("Display endpoint details")
 
     def get_parser(self, prog_name):
-        parser = super(ShowEndpoint, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'endpoint',
             metavar='<endpoint>',
-            help=_('Endpoint to display (endpoint ID, service ID,'
-                   ' service name, service type)'),
+            help=_(
+                'Endpoint to display (endpoint ID, service ID,'
+                ' service name, service type)'
+            ),
         )
         return parser
 
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
-        endpoint = utils.find_resource(identity_client.endpoints,
-                                       parsed_args.endpoint)
+        endpoint = utils.find_resource(
+            identity_client.endpoints, parsed_args.endpoint
+        )
 
         service = common.find_service(identity_client, endpoint.service_id)
 
@@ -276,4 +417,4 @@ class ShowEndpoint(command.ShowOne):
         info.update(endpoint._info)
         info['service_name'] = get_service_name(service)
         info['service_type'] = service.type
-        return zip(*sorted(six.iteritems(info)))
+        return zip(*sorted(info.items()))
