@@ -30,17 +30,40 @@ MANDATORY_PARAMETERS = {
     RULE_TYPE_MINIMUM_BANDWIDTH: {'min_kbps', 'direction'},
     RULE_TYPE_MINIMUM_PACKET_RATE: {'min_kpps', 'direction'},
     RULE_TYPE_DSCP_MARKING: {'dscp_mark'},
-    RULE_TYPE_BANDWIDTH_LIMIT: {'max_kbps'}}
+    RULE_TYPE_BANDWIDTH_LIMIT: {'max_kbps'},
+}
 OPTIONAL_PARAMETERS = {
     RULE_TYPE_MINIMUM_BANDWIDTH: set(),
     RULE_TYPE_MINIMUM_PACKET_RATE: set(),
     RULE_TYPE_DSCP_MARKING: set(),
-    RULE_TYPE_BANDWIDTH_LIMIT: {'direction', 'max_burst_kbps'}}
+    RULE_TYPE_BANDWIDTH_LIMIT: {'direction', 'max_burst_kbps'},
+}
 DIRECTION_EGRESS = 'egress'
 DIRECTION_INGRESS = 'ingress'
 DIRECTION_ANY = 'any'
-DSCP_VALID_MARKS = [0, 8, 10, 12, 14, 16, 18, 20, 22, 24, 26, 28, 30, 32,
-                    34, 36, 38, 40, 46, 48, 56]
+DSCP_VALID_MARKS = [
+    0,
+    8,
+    10,
+    12,
+    14,
+    16,
+    18,
+    20,
+    22,
+    24,
+    26,
+    28,
+    30,
+    32,
+    34,
+    36,
+    38,
+    40,
+    46,
+    48,
+    56,
+]
 
 ACTION_CREATE = 'create'
 ACTION_DELETE = 'delete'
@@ -53,9 +76,7 @@ def _get_columns(item):
     column_map = {}
     hidden_columns = ['location', 'tenant_id']
     return utils.get_osc_show_columns_for_sdk_resource(
-        item,
-        column_map,
-        hidden_columns
+        item, column_map, hidden_columns
     )
 
 
@@ -63,31 +84,38 @@ def _check_type_parameters(attrs, type, is_create):
     req_params = MANDATORY_PARAMETERS[type]
     opt_params = OPTIONAL_PARAMETERS[type]
     type_params = req_params | opt_params
-    notreq_params = set(itertools.chain(
-        *[v for k, v in MANDATORY_PARAMETERS.items() if k != type]))
+    notreq_params = set(
+        itertools.chain(
+            *[v for k, v in MANDATORY_PARAMETERS.items() if k != type]
+        )
+    )
     notreq_params -= type_params
     if is_create and None in map(attrs.get, req_params):
-        msg = (_('"Create" rule command for type "%(rule_type)s" requires '
-                 'arguments: %(args)s') %
-               {'rule_type': type, 'args': ", ".join(sorted(req_params))})
+        msg = _(
+            '"Create" rule command for type "%(rule_type)s" requires '
+            'arguments: %(args)s'
+        ) % {'rule_type': type, 'args': ", ".join(sorted(req_params))}
         raise exceptions.CommandError(msg)
     if set(attrs.keys()) & notreq_params:
-        msg = (_('Rule type "%(rule_type)s" only requires arguments: %(args)s')
-               % {'rule_type': type, 'args': ", ".join(sorted(type_params))})
+        msg = _(
+            'Rule type "%(rule_type)s" only requires arguments: %(args)s'
+        ) % {'rule_type': type, 'args': ", ".join(sorted(type_params))}
         raise exceptions.CommandError(msg)
 
 
 def _get_attrs(network_client, parsed_args, is_create=False):
     attrs = {}
-    qos = network_client.find_qos_policy(parsed_args.qos_policy,
-                                         ignore_missing=False)
+    qos = network_client.find_qos_policy(
+        parsed_args.qos_policy, ignore_missing=False
+    )
     attrs['qos_policy_id'] = qos.id
     if not is_create:
         attrs['id'] = parsed_args.id
         rule_type = _find_rule_type(qos, parsed_args.id)
         if not rule_type:
-            msg = (_('Rule ID %(rule_id)s not found') %
-                   {'rule_id': parsed_args.id})
+            msg = _('Rule ID %(rule_id)s not found') % {
+                'rule_id': parsed_args.id
+            }
             raise exceptions.CommandError(msg)
     else:
         rule_type = parsed_args.type
@@ -112,9 +140,10 @@ def _get_attrs(network_client, parsed_args, is_create=False):
         if rule_type == RULE_TYPE_MINIMUM_PACKET_RATE:
             attrs['direction'] = DIRECTION_ANY
         else:
-            msg = (_('Direction "any" can only be used with '
-                     '%(rule_type_min_pps)s rule type') %
-                   {'rule_type_min_pps': RULE_TYPE_MINIMUM_PACKET_RATE})
+            msg = _(
+                'Direction "any" can only be used with '
+                '%(rule_type_min_pps)s rule type'
+            ) % {'rule_type_min_pps': RULE_TYPE_MINIMUM_PACKET_RATE}
             raise exceptions.CommandError(msg)
     _check_type_parameters(attrs, rule_type, is_create)
     return attrs
@@ -130,8 +159,7 @@ def _get_item_properties(item, fields):
 
 def _rule_action_call(client, action, rule_type):
     rule_type = rule_type.replace('-', '_')
-    func_name = '%(action)s_qos_%(rule_type)s_rule' % {'action': action,
-                                                       'rule_type': rule_type}
+    func_name = f'{action}_qos_{rule_type}_rule'
     return getattr(client, func_name)
 
 
@@ -147,81 +175,91 @@ def _add_rule_arguments(parser):
         dest='max_kbps',
         metavar='<max-kbps>',
         type=int,
-        help=_('Maximum bandwidth in kbps')
+        help=_('Maximum bandwidth in kbps'),
     )
     parser.add_argument(
         '--max-burst-kbits',
         dest='max_burst_kbits',
         metavar='<max-burst-kbits>',
         type=int,
-        help=_('Maximum burst in kilobits, 0 or not specified means '
-               'automatic, which is 80%% of the bandwidth limit, which works '
-               'for typical TCP traffic. For details check the QoS user '
-               'workflow.')
+        help=_(
+            'Maximum burst in kilobits, 0 or not specified means '
+            'automatic, which is 80%% of the bandwidth limit, which works '
+            'for typical TCP traffic. For details check the QoS user '
+            'workflow.'
+        ),
     )
     parser.add_argument(
         '--dscp-mark',
         dest='dscp_mark',
         metavar='<dscp-mark>',
         type=int,
-        help=_('DSCP mark: value can be 0, even numbers from 8-56, '
-               'excluding 42, 44, 50, 52, and 54')
+        help=_(
+            'DSCP mark: value can be 0, even numbers from 8-56, '
+            'excluding 42, 44, 50, 52, and 54'
+        ),
     )
     parser.add_argument(
         '--min-kbps',
         dest='min_kbps',
         metavar='<min-kbps>',
         type=int,
-        help=_('Minimum guaranteed bandwidth in kbps')
+        help=_('Minimum guaranteed bandwidth in kbps'),
     )
     parser.add_argument(
         '--min-kpps',
         dest='min_kpps',
         metavar='<min-kpps>',
         type=int,
-        help=_('Minimum guaranteed packet rate in kpps')
+        help=_('Minimum guaranteed packet rate in kpps'),
     )
     direction_group = parser.add_mutually_exclusive_group()
     direction_group.add_argument(
         '--ingress',
         action='store_true',
-        help=_("Ingress traffic direction from the project point of view")
+        help=_("Ingress traffic direction from the project point of view"),
     )
     direction_group.add_argument(
         '--egress',
         action='store_true',
-        help=_("Egress traffic direction from the project point of view")
+        help=_("Egress traffic direction from the project point of view"),
     )
     direction_group.add_argument(
         '--any',
         action='store_true',
-        help=_("Any traffic direction from the project point of view. Can be "
-               "used only with minimum packet rate rule.")
+        help=_(
+            "Any traffic direction from the project point of view. Can be "
+            "used only with minimum packet rate rule."
+        ),
     )
 
 
-class CreateNetworkQosRule(command.ShowOne,
-                           common.NeutronCommandWithExtraArgs):
+class CreateNetworkQosRule(
+    command.ShowOne, common.NeutronCommandWithExtraArgs
+):
     _description = _("Create new Network QoS rule")
 
     def get_parser(self, prog_name):
-        parser = super(CreateNetworkQosRule, self).get_parser(
-            prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'qos_policy',
             metavar='<qos-policy>',
-            help=_('QoS policy that contains the rule (name or ID)')
+            help=_('QoS policy that contains the rule (name or ID)'),
         )
         parser.add_argument(
             '--type',
             metavar='<type>',
             required=True,
-            choices=[RULE_TYPE_MINIMUM_BANDWIDTH,
-                     RULE_TYPE_MINIMUM_PACKET_RATE,
-                     RULE_TYPE_DSCP_MARKING,
-                     RULE_TYPE_BANDWIDTH_LIMIT],
-            help=(_('QoS rule type (%s)') %
-                  ", ".join(MANDATORY_PARAMETERS.keys()))
+            choices=[
+                RULE_TYPE_MINIMUM_BANDWIDTH,
+                RULE_TYPE_MINIMUM_PACKET_RATE,
+                RULE_TYPE_DSCP_MARKING,
+                RULE_TYPE_BANDWIDTH_LIMIT,
+            ],
+            help=(
+                _('QoS rule type (%s)')
+                % ", ".join(MANDATORY_PARAMETERS.keys())
+            ),
         )
         _add_rule_arguments(parser)
         return parser
@@ -231,12 +269,13 @@ class CreateNetworkQosRule(command.ShowOne,
         try:
             attrs = _get_attrs(network_client, parsed_args, is_create=True)
             attrs.update(
-                self._parse_extra_properties(parsed_args.extra_properties))
+                self._parse_extra_properties(parsed_args.extra_properties)
+            )
             obj = _rule_action_call(
-                network_client, ACTION_CREATE, parsed_args.type)(
-                attrs.pop('qos_policy_id'), **attrs)
+                network_client, ACTION_CREATE, parsed_args.type
+            )(attrs.pop('qos_policy_id'), **attrs)
         except Exception as e:
-            msg = (_('Failed to create Network QoS rule: %(e)s') % {'e': e})
+            msg = _('Failed to create Network QoS rule: %(e)s') % {'e': e}
             raise exceptions.CommandError(msg)
         display_columns, columns = _get_columns(obj)
         data = utils.get_item_properties(obj, columns)
@@ -247,16 +286,16 @@ class DeleteNetworkQosRule(command.Command):
     _description = _("Delete Network QoS rule")
 
     def get_parser(self, prog_name):
-        parser = super(DeleteNetworkQosRule, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'qos_policy',
             metavar='<qos-policy>',
-            help=_('QoS policy that contains the rule (name or ID)')
+            help=_('QoS policy that contains the rule (name or ID)'),
         )
         parser.add_argument(
             'id',
             metavar='<rule-id>',
-            help=_('Network QoS rule to delete (ID)')
+            help=_('Network QoS rule to delete (ID)'),
         )
         return parser
 
@@ -264,16 +303,19 @@ class DeleteNetworkQosRule(command.Command):
         network_client = self.app.client_manager.network
         rule_id = parsed_args.id
         try:
-            qos = network_client.find_qos_policy(parsed_args.qos_policy,
-                                                 ignore_missing=False)
+            qos = network_client.find_qos_policy(
+                parsed_args.qos_policy, ignore_missing=False
+            )
             rule_type = _find_rule_type(qos, rule_id)
             if not rule_type:
-                raise Exception('Rule %s not found' % rule_id)
+                raise Exception(f'Rule {rule_id} not found')
             _rule_action_call(network_client, ACTION_DELETE, rule_type)(
-                rule_id, qos.id)
+                rule_id, qos.id
+            )
         except Exception as e:
-            msg = (_('Failed to delete Network QoS rule ID "%(rule)s": %(e)s')
-                   % {'rule': rule_id, 'e': e})
+            msg = _(
+                'Failed to delete Network QoS rule ID "%(rule)s": %(e)s'
+            ) % {'rule': rule_id, 'e': e}
             raise exceptions.CommandError(msg)
 
 
@@ -281,11 +323,11 @@ class ListNetworkQosRule(command.Lister):
     _description = _("List Network QoS rules")
 
     def get_parser(self, prog_name):
-        parser = super(ListNetworkQosRule, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'qos_policy',
             metavar='<qos-policy>',
-            help=_('QoS policy that contains the rule (name or ID)')
+            help=_('QoS policy that contains the rule (name or ID)'),
         )
         return parser
 
@@ -313,27 +355,30 @@ class ListNetworkQosRule(command.Lister):
             'DSCP mark',
             'Direction',
         )
-        qos = client.find_qos_policy(parsed_args.qos_policy,
-                                     ignore_missing=False)
+        qos = client.find_qos_policy(
+            parsed_args.qos_policy, ignore_missing=False
+        )
         data = qos.rules
-        return (column_headers,
-                (_get_item_properties(s, columns) for s in data))
+        return (
+            column_headers,
+            (_get_item_properties(s, columns) for s in data),
+        )
 
 
 class SetNetworkQosRule(common.NeutronCommandWithExtraArgs):
     _description = _("Set Network QoS rule properties")
 
     def get_parser(self, prog_name):
-        parser = super(SetNetworkQosRule, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'qos_policy',
             metavar='<qos-policy>',
-            help=_('QoS policy that contains the rule (name or ID)')
+            help=_('QoS policy that contains the rule (name or ID)'),
         )
         parser.add_argument(
             'id',
             metavar='<rule-id>',
-            help=_('Network QoS rule to delete (ID)')
+            help=_('Network QoS rule to delete (ID)'),
         )
         _add_rule_arguments(parser)
         return parser
@@ -341,22 +386,28 @@ class SetNetworkQosRule(common.NeutronCommandWithExtraArgs):
     def take_action(self, parsed_args):
         network_client = self.app.client_manager.network
         try:
-            qos = network_client.find_qos_policy(parsed_args.qos_policy,
-                                                 ignore_missing=False)
+            qos = network_client.find_qos_policy(
+                parsed_args.qos_policy, ignore_missing=False
+            )
             rule_type = _find_rule_type(qos, parsed_args.id)
             if not rule_type:
                 raise Exception('Rule not found')
             attrs = _get_attrs(network_client, parsed_args)
             attrs.update(
-                self._parse_extra_properties(parsed_args.extra_properties))
+                self._parse_extra_properties(parsed_args.extra_properties)
+            )
             qos_id = attrs.pop('qos_policy_id')
-            qos_rule = _rule_action_call(network_client, ACTION_FIND,
-                                         rule_type)(attrs.pop('id'), qos_id)
+            qos_rule = _rule_action_call(
+                network_client, ACTION_FIND, rule_type
+            )(attrs.pop('id'), qos_id)
             _rule_action_call(network_client, ACTION_SET, rule_type)(
-                qos_rule, qos_id, **attrs)
+                qos_rule, qos_id, **attrs
+            )
         except Exception as e:
-            msg = (_('Failed to set Network QoS rule ID "%(rule)s": %(e)s') %
-                   {'rule': parsed_args.id, 'e': e})
+            msg = _('Failed to set Network QoS rule ID "%(rule)s": %(e)s') % {
+                'rule': parsed_args.id,
+                'e': e,
+            }
             raise exceptions.CommandError(msg)
 
 
@@ -364,16 +415,16 @@ class ShowNetworkQosRule(command.ShowOne):
     _description = _("Display Network QoS rule details")
 
     def get_parser(self, prog_name):
-        parser = super(ShowNetworkQosRule, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'qos_policy',
             metavar='<qos-policy>',
-            help=_('QoS policy that contains the rule (name or ID)')
+            help=_('QoS policy that contains the rule (name or ID)'),
         )
         parser.add_argument(
             'id',
             metavar='<rule-id>',
-            help=_('Network QoS rule to delete (ID)')
+            help=_('Network QoS rule to delete (ID)'),
         )
         return parser
 
@@ -381,16 +432,20 @@ class ShowNetworkQosRule(command.ShowOne):
         network_client = self.app.client_manager.network
         rule_id = parsed_args.id
         try:
-            qos = network_client.find_qos_policy(parsed_args.qos_policy,
-                                                 ignore_missing=False)
+            qos = network_client.find_qos_policy(
+                parsed_args.qos_policy, ignore_missing=False
+            )
             rule_type = _find_rule_type(qos, rule_id)
             if not rule_type:
                 raise Exception('Rule not found')
             obj = _rule_action_call(network_client, ACTION_SHOW, rule_type)(
-                rule_id, qos.id)
+                rule_id, qos.id
+            )
         except Exception as e:
-            msg = (_('Failed to set Network QoS rule ID "%(rule)s": %(e)s') %
-                   {'rule': rule_id, 'e': e})
+            msg = _('Failed to set Network QoS rule ID "%(rule)s": %(e)s') % {
+                'rule': rule_id,
+                'e': e,
+            }
             raise exceptions.CommandError(msg)
         display_columns, columns = _get_columns(obj)
         data = utils.get_item_properties(obj, columns)
