@@ -20,112 +20,57 @@ from osc_lib.cli import parseractions
 from osc_lib import exceptions
 from osc_lib import utils
 
+from openstackclient.api import compute_v2
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
 from openstackclient.network import common
-from openstackclient.network import sdk_utils
 from openstackclient.network import utils as network_utils
 
-
 LOG = logging.getLogger(__name__)
 
 
-def _format_security_group_rule_show(obj):
-    data = network_utils.transform_compute_security_group_rule(obj)
-    return zip(*sorted(data.items()))
-
-
-def _format_network_port_range(rule):
-    # Display port range or ICMP type and code. For example:
-    # - ICMP type: 'type=3'
-    # - ICMP type and code: 'type=3:code=0'
-    # - ICMP code: Not supported
-    # - Matching port range: '443:443'
-    # - Different port range: '22:24'
-    # - Single port: '80:80'
-    # - No port range: ''
-    port_range = ''
-    if _is_icmp_protocol(rule['protocol']):
-        if rule['port_range_min']:
-            port_range += 'type=' + str(rule['port_range_min'])
-        if rule['port_range_max']:
-            port_range += ':code=' + str(rule['port_range_max'])
-    elif rule['port_range_min'] or rule['port_range_max']:
-        port_range_min = str(rule['port_range_min'])
-        port_range_max = str(rule['port_range_max'])
-        if rule['port_range_min'] is None:
-            port_range_min = port_range_max
-        if rule['port_range_max'] is None:
-            port_range_max = port_range_min
-        port_range = port_range_min + ':' + port_range_max
-    return port_range
-
-
-def _format_remote_ip_prefix(rule):
-    remote_ip_prefix = rule['remote_ip_prefix']
-    if remote_ip_prefix is None:
-        ethertype = rule['ether_type']
-        if ethertype == 'IPv4':
-            remote_ip_prefix = '0.0.0.0/0'
-        elif ethertype == 'IPv6':
-            remote_ip_prefix = '::/0'
-    return remote_ip_prefix
-
-
 def _get_columns(item):
-    column_map = {
-        'tenant_id': 'project_id',
-    }
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(item, column_map)
-
-
-def _convert_to_lowercase(string):
-    return string.lower()
-
-
-def _convert_ipvx_case(string):
-    if string.lower() == 'ipv4':
-        return 'IPv4'
-    if string.lower() == 'ipv6':
-        return 'IPv6'
-    return string
-
-
-def _is_icmp_protocol(protocol):
-    # NOTE(rtheis): Neutron has deprecated protocol icmpv6.
-    # However, while the OSC CLI doesn't document the protocol,
-    # the code must still handle it. In addition, handle both
-    # protocol names and numbers.
-    if protocol in ['icmp', 'icmpv6', 'ipv6-icmp', '1', '58']:
-        return True
-    else:
-        return False
+    column_map = {}
+    hidden_columns = ['location', 'tenant_id']
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item, column_map, hidden_columns
+    )
 
 
 # TODO(abhiraut): Use the SDK resource mapped attribute names once the
 # OSC minimum requirements include SDK 1.0.
-class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
+class CreateSecurityGroupRule(
+    common.NetworkAndComputeShowOne, common.NeutronCommandWithExtraArgs
+):
     _description = _("Create a new security group rule")
 
     def update_parser_common(self, parser):
         parser.add_argument(
             'group',
             metavar='<group>',
-            help=_("Create rule in this security group (name or ID)")
+            help=_("Create rule in this security group (name or ID)"),
         )
         remote_group = parser.add_mutually_exclusive_group()
         remote_group.add_argument(
             "--remote-ip",
             metavar="<ip-address>",
-            help=_("Remote IP address block (may use CIDR notation; "
-                   "default for IPv4 rule: 0.0.0.0/0, "
-                   "default for IPv6 rule: ::/0)"),
+            help=_(
+                "Remote IP address block (may use CIDR notation; "
+                "default for IPv4 rule: 0.0.0.0/0, "
+                "default for IPv6 rule: ::/0)"
+            ),
         )
         remote_group.add_argument(
             "--remote-group",
             metavar="<group>",
             help=_("Remote security group (name or ID)"),
         )
+        if self.is_neutron:
+            remote_group.add_argument(
+                "--remote-address-group",
+                metavar="<group>",
+                help=_("Remote address group (name or ID)"),
+            )
 
         # NOTE(efried): The --dst-port, --protocol, and --proto options exist
         # for both nova-network and neutron, but differ slightly. For the sake
@@ -142,10 +87,12 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
             '--dst-port',
             metavar='<port-range>',
             action=parseractions.RangeAction,
-            help=_("Destination port, may be a single port or a starting and "
-                   "ending port range: 137:139. Required for IP protocols TCP "
-                   "and UDP. Ignored for ICMP IP protocols."),
-            **dst_port_default
+            help=_(
+                "Destination port, may be a single port or a starting and "
+                "ending port range: 137:139. Required for IP protocols TCP "
+                "and UDP. Ignored for ICMP IP protocols."
+            ),
+            **dst_port_default,
         )
 
         # NOTE(rtheis): Support either protocol option name for now.
@@ -162,7 +109,8 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
             "IP protocol (ah, dccp, egp, esp, gre, icmp, igmp, ipv6-encap, "
             "ipv6-frag, ipv6-icmp, ipv6-nonxt, ipv6-opts, ipv6-route, ospf, "
             "pgm, rsvp, sctp, tcp, udp, udplite, vrrp and integer "
-            "representations [0-255] or any; default: any (all protocols))")
+            "representations [0-255] or any; default: any (all protocols))"
+        )
         if self.is_nova_network:
             protocol_help = protocol_help_compute
         elif self.is_neutron:
@@ -170,22 +118,23 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
         else:
             # Docs build: compose help for both nova-network and neutron
             protocol_help = self.split_help(
-                protocol_help_network, protocol_help_compute)
+                protocol_help_network, protocol_help_compute
+            )
 
         protocol_group.add_argument(
             '--protocol',
             metavar='<protocol>',
-            type=_convert_to_lowercase,
+            type=network_utils.convert_to_lowercase,
             help=protocol_help,
-            **proto_choices
+            **proto_choices,
         )
         if not self.is_docs_build:
             protocol_group.add_argument(
                 '--proto',
                 metavar='<proto>',
-                type=_convert_to_lowercase,
+                type=network_utils.convert_to_lowercase,
                 help=argparse.SUPPRESS,
-                **proto_choices
+                **proto_choices,
             )
 
         return parser
@@ -195,92 +144,71 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
             '--description',
             metavar='<description>',
             help=self.enhance_help_neutron(
-                _("Set security group rule description"))
+                _("Set security group rule description")
+            ),
         )
         parser.add_argument(
             '--icmp-type',
             metavar='<icmp-type>',
             type=int,
             help=self.enhance_help_neutron(
-                _("ICMP type for ICMP IP protocols"))
+                _("ICMP type for ICMP IP protocols")
+            ),
         )
         parser.add_argument(
             '--icmp-code',
             metavar='<icmp-code>',
             type=int,
             help=self.enhance_help_neutron(
-                _("ICMP code for ICMP IP protocols"))
+                _("ICMP code for ICMP IP protocols")
+            ),
         )
         direction_group = parser.add_mutually_exclusive_group()
         direction_group.add_argument(
             '--ingress',
             action='store_true',
             help=self.enhance_help_neutron(
-                _("Rule applies to incoming network traffic (default)"))
+                _("Rule applies to incoming network traffic (default)")
+            ),
         )
         direction_group.add_argument(
             '--egress',
             action='store_true',
             help=self.enhance_help_neutron(
-                _("Rule applies to outgoing network traffic"))
+                _("Rule applies to outgoing network traffic")
+            ),
         )
         parser.add_argument(
             '--ethertype',
             metavar='<ethertype>',
             choices=['IPv4', 'IPv6'],
-            type=_convert_ipvx_case,
+            type=network_utils.convert_ipvx_case,
             help=self.enhance_help_neutron(
-                _("Ethertype of network traffic "
-                  "(IPv4, IPv6; default: based on IP protocol)"))
+                _(
+                    "Ethertype of network traffic "
+                    "(IPv4, IPv6; default: based on IP protocol)"
+                )
+            ),
         )
         parser.add_argument(
             '--project',
             metavar='<project>',
-            help=self.enhance_help_neutron(_("Owner's project (name or ID)"))
+            help=self.enhance_help_neutron(_("Owner's project (name or ID)")),
         )
         identity_common.add_project_domain_option_to_parser(
-            parser, enhance_help=self.enhance_help_neutron)
+            parser, enhance_help=self.enhance_help_neutron
+        )
         return parser
 
-    def _get_protocol(self, parsed_args, default_protocol='any'):
-        protocol = default_protocol
-        if parsed_args.protocol is not None:
-            protocol = parsed_args.protocol
-        if parsed_args.proto is not None:
-            protocol = parsed_args.proto
-        if protocol == 'any':
-            protocol = None
-        return protocol
-
-    def _get_ethertype(self, parsed_args, protocol):
-        ethertype = 'IPv4'
-        if parsed_args.ethertype is not None:
-            ethertype = parsed_args.ethertype
-        elif self._is_ipv6_protocol(protocol):
-            ethertype = 'IPv6'
-        return ethertype
-
-    def _is_ipv6_protocol(self, protocol):
-        # NOTE(rtheis): Neutron has deprecated protocol icmpv6.
-        # However, while the OSC CLI doesn't document the protocol,
-        # the code must still handle it. In addition, handle both
-        # protocol names and numbers.
-        if (protocol is not None and protocol.startswith('ipv6-') or
-                protocol in ['icmpv6', '41', '43', '44', '58', '59', '60']):
-            return True
-        else:
-            return False
-
     def take_action_network(self, client, parsed_args):
         # Get the security group ID to hold the rule.
         security_group_id = client.find_security_group(
-            parsed_args.group,
-            ignore_missing=False
+            parsed_args.group, ignore_missing=False
         ).id
 
         # Build the create attributes.
         attrs = {}
-        attrs['protocol'] = self._get_protocol(parsed_args)
+        attrs['protocol'] = network_utils.get_protocol(parsed_args)
 
         if parsed_args.description is not None:
             attrs['description'] = parsed_args.description
@@ -294,24 +222,31 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
 
         # NOTE(rtheis): Use ethertype specified else default based
         # on IP protocol.
-        attrs['ethertype'] = self._get_ethertype(parsed_args,
-                                                 attrs['protocol'])
+        attrs['ethertype'] = network_utils.get_ethertype(
+            parsed_args, attrs['protocol']
+        )
 
         # NOTE(rtheis): Validate the port range and ICMP type and code.
         # It would be ideal if argparse could do this.
-        if parsed_args.dst_port and (parsed_args.icmp_type or
-                                     parsed_args.icmp_code):
-            msg = _('Argument --dst-port not allowed with arguments '
-                    '--icmp-type and --icmp-code')
+        if parsed_args.dst_port and (
+            parsed_args.icmp_type or parsed_args.icmp_code
+        ):
+            msg = _(
+                'Argument --dst-port not allowed with arguments '
+                '--icmp-type and --icmp-code'
+            )
             raise exceptions.CommandError(msg)
         if parsed_args.icmp_type is None and parsed_args.icmp_code is not None:
             msg = _('Argument --icmp-type required with argument --icmp-code')
             raise exceptions.CommandError(msg)
-        is_icmp_protocol = _is_icmp_protocol(attrs['protocol'])
-        if not is_icmp_protocol and (parsed_args.icmp_type or
-                                     parsed_args.icmp_code):
-            msg = _('ICMP IP protocol required with arguments '
-                    '--icmp-type and --icmp-code')
+        is_icmp_protocol = network_utils.is_icmp_protocol(attrs['protocol'])
+        if not is_icmp_protocol and (
+            parsed_args.icmp_type or parsed_args.icmp_code
+        ):
+            msg = _(
+                'ICMP IP protocol required with arguments '
+                '--icmp-type and --icmp-code'
+            )
             raise exceptions.CommandError(msg)
         # NOTE(rtheis): For backwards compatibility, continue ignoring
         # the destination port range when an ICMP IP protocol is specified.
@@ -325,8 +260,11 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
 
         if parsed_args.remote_group is not None:
             attrs['remote_group_id'] = client.find_security_group(
-                parsed_args.remote_group,
-                ignore_missing=False
+                parsed_args.remote_group, ignore_missing=False
+            ).id
+        elif parsed_args.remote_address_group is not None:
+            attrs['remote_address_group_id'] = client.find_address_group(
+                parsed_args.remote_address_group, ignore_missing=False
             ).id
         elif parsed_args.remote_ip is not None:
             attrs['remote_ip_prefix'] = parsed_args.remote_ip
@@ -342,7 +280,11 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
                 parsed_args.project,
                 parsed_args.project_domain,
             ).id
-            attrs['tenant_id'] = project_id
+            attrs['project_id'] = project_id
+
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties)
+        )
 
         # Create and show the security group rule.
         obj = client.create_security_group_rule(**attrs)
@@ -351,8 +293,10 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
         return (display_columns, data)
 
     def take_action_compute(self, client, parsed_args):
-        group = client.api.security_group_find(parsed_args.group)
-        protocol = self._get_protocol(parsed_args, default_protocol='tcp')
+        group = compute_v2.find_security_group(client, parsed_args.group)
+        protocol = network_utils.get_protocol(
+            parsed_args, default_protocol='tcp'
+        )
         if protocol == 'icmp':
             from_port, to_port = -1, -1
         else:
@@ -360,15 +304,16 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
 
         remote_ip = None
         if parsed_args.remote_group is not None:
-            parsed_args.remote_group = client.api.security_group_find(
-                parsed_args.remote_group,
+            parsed_args.remote_group = compute_v2.find_security_group(
+                client, parsed_args.remote_group
             )['id']
         if parsed_args.remote_ip is not None:
             remote_ip = parsed_args.remote_ip
         else:
             remote_ip = '0.0.0.0/0'
 
-        obj = client.api.security_group_rule_create(
+        obj = compute_v2.create_security_group_rule(
+            client,
             security_group_id=group['id'],
             ip_protocol=protocol,
             from_port=from_port,
@@ -376,7 +321,7 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
             remote_ip=remote_ip,
             remote_group=parsed_args.remote_group,
         )
-        return _format_security_group_rule_show(obj)
+        return network_utils.format_security_group_rule_show(obj)
 
 
 class DeleteSecurityGroupRule(common.NetworkAndComputeDelete):
@@ -391,17 +336,16 @@ class DeleteSecurityGroupRule(common.NetworkAndComputeDelete):
             'rule',
             metavar='<rule>',
             nargs="+",
-            help=_("Security group rule(s) to delete (ID only)")
+            help=_("Security group rule(s) to delete (ID only)"),
         )
         return parser
 
     def take_action_network(self, client, parsed_args):
-        obj = client.find_security_group_rule(
-            self.r, ignore_missing=False)
+        obj = client.find_security_group_rule(self.r, ignore_missing=False)
         client.delete_security_group_rule(obj)
 
     def take_action_compute(self, client, parsed_args):
-        client.api.security_group_rule_delete(self.r)
+        compute_v2.delete_security_group_rule(client, self.r)
 
 
 class ListSecurityGroupRule(common.NetworkAndComputeLister):
@@ -414,8 +358,8 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
         Create port_range column from port_range_min and port_range_max
         """
         rule = rule.to_dict()
-        rule['port_range'] = _format_network_port_range(rule)
-        rule['remote_ip_prefix'] = _format_remote_ip_prefix(rule)
+        rule['port_range'] = network_utils.format_network_port_range(rule)
+        rule['remote_ip_prefix'] = network_utils.format_remote_ip_prefix(rule)
         return rule
 
     def update_parser_common(self, parser):
@@ -423,7 +367,7 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
             'group',
             metavar='<group>',
             nargs='?',
-            help=_("List all rules in this security group (name or ID)")
+            help=_("List all rules in this security group (name or ID)"),
         )
         return parser
 
@@ -435,46 +379,54 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
                 '--all-projects',
                 action='store_true',
                 default=False,
-                help=argparse.SUPPRESS
+                help=argparse.SUPPRESS,
             )
 
         parser.add_argument(
             '--protocol',
             metavar='<protocol>',
-            type=_convert_to_lowercase,
+            type=network_utils.convert_to_lowercase,
             help=self.enhance_help_neutron(
-                _("List rules by the IP protocol (ah, dhcp, egp, esp, gre, "
-                  "icmp, igmp, ipv6-encap, ipv6-frag, ipv6-icmp, ipv6-nonxt, "
-                  "ipv6-opts, ipv6-route, ospf, pgm, rsvp, sctp, tcp, udp, "
-                  "udplite, vrrp and integer representations [0-255] or any; "
-                  "default: any (all protocols))"))
+                _(
+                    "List rules by the IP protocol (ah, dhcp, egp, esp, gre, "
+                    "icmp, igmp, ipv6-encap, ipv6-frag, ipv6-icmp, "
+                    "ipv6-nonxt, ipv6-opts, ipv6-route, ospf, pgm, rsvp, "
+                    "sctp, tcp, udp, udplite, vrrp and integer "
+                    "representations [0-255] or any; "
+                    "default: any (all protocols))"
+                )
+            ),
         )
         parser.add_argument(
             '--ethertype',
             metavar='<ethertype>',
-            type=_convert_to_lowercase,
+            type=network_utils.convert_to_lowercase,
             help=self.enhance_help_neutron(
-                _("List rules by the Ethertype (IPv4 or IPv6)"))
+                _("List rules by the Ethertype (IPv4 or IPv6)")
+            ),
         )
         direction_group = parser.add_mutually_exclusive_group()
         direction_group.add_argument(
             '--ingress',
             action='store_true',
             help=self.enhance_help_neutron(
-                _("List rules applied to incoming network traffic"))
+                _("List rules applied to incoming network traffic")
+            ),
         )
         direction_group.add_argument(
             '--egress',
             action='store_true',
             help=self.enhance_help_neutron(
-                _("List rules applied to outgoing network traffic"))
+                _("List rules applied to outgoing network traffic")
+            ),
         )
         parser.add_argument(
             '--long',
             action='store_true',
             default=False,
             help=self.enhance_help_neutron(
-                _("List additional fields in output"))
+                _("**Deprecated** This argument is no longer needed")
+            ),
         )
         return parser
 
@@ -484,7 +436,8 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
             action='store_true',
             default=False,
             help=self.enhance_help_nova_network(
-                _("Display information from all projects (admin only)"))
+                _("Display information from all projects (admin only)")
+            ),
         )
         if not self.is_docs_build:
             # Accept but hide the argument for consistency with network.
@@ -493,7 +446,7 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
                 '--long',
                 action='store_false',
                 default=False,
-                help=argparse.SUPPRESS
+                help=argparse.SUPPRESS,
             )
         return parser
 
@@ -504,15 +457,22 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
             'Ethertype',
             'IP Range',
             'Port Range',
+            'Direction',
+            'Remote Security Group',
         )
-        if parsed_args.long:
-            column_headers = column_headers + ('Direction',)
-        column_headers = column_headers + ('Remote Security Group',)
+        if self.is_neutron:
+            column_headers = column_headers + ('Remote Address Group',)
         if parsed_args.group is None:
             column_headers = column_headers + ('Security Group',)
         return column_headers
 
     def take_action_network(self, client, parsed_args):
+        if parsed_args.long:
+            msg = _(
+                "The --long option has been deprecated and is no longer needed"
+            )
+            self.log.warning(msg)
+
         column_headers = self._get_column_headers(parsed_args)
         columns = (
             'id',
@@ -520,10 +480,10 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
             'ether_type',
             'remote_ip_prefix',
             'port_range',
+            'direction',
+            'remote_group_id',
+            'remote_address_group_id',
         )
-        if parsed_args.long:
-            columns = columns + ('direction',)
-        columns = columns + ('remote_group_id',)
 
         # Get the security group rules using the requested query.
         query = {}
@@ -532,8 +492,7 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
             # does not contain security group rules resources. So use
             # the security group ID in a query to get the resources.
             security_group_id = client.find_security_group(
-                parsed_args.group,
-                ignore_missing=False
+                parsed_args.group, ignore_missing=False
             ).id
             query = {'security_group_id': security_group_id}
         else:
@@ -551,10 +510,16 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
             for r in client.security_group_rules(**query)
         ]
 
-        return (column_headers,
-                (utils.get_dict_properties(
-                    s, columns,
-                ) for s in rules))
+        return (
+            column_headers,
+            (
+                utils.get_dict_properties(
+                    s,
+                    columns,
+                )
+                for s in rules
+            ),
+        )
 
     def take_action_compute(self, client, parsed_args):
         column_headers = self._get_column_headers(parsed_args)
@@ -569,15 +534,16 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
 
         rules_to_list = []
         if parsed_args.group is not None:
-            group = client.api.security_group_find(
-                parsed_args.group,
+            security_group = compute_v2.find_security_group(
+                client, parsed_args.group
             )
-            rules_to_list = group['rules']
+            rules_to_list = security_group['rules']
         else:
             columns = columns + ('parent_group_id',)
-            search = {'all_tenants': parsed_args.all_projects}
-            for group in client.api.security_group_list(search_opts=search):
-                rules_to_list.extend(group['rules'])
+            for security_group in compute_v2.list_security_groups(
+                client, all_projects=parsed_args.all_projects
+            ):
+                rules_to_list.extend(security_group['rules'])
 
         # NOTE(rtheis): Turn the raw rules into resources.
         rules = []
@@ -590,10 +556,16 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
             #     network_utils.transform_compute_security_group_rule(rule),
             # ))
 
-        return (column_headers,
-                (utils.get_dict_properties(
-                    s, columns,
-                ) for s in rules))
+        return (
+            column_headers,
+            (
+                utils.get_dict_properties(
+                    s,
+                    columns,
+                )
+                for s in rules
+            ),
+        )
 
 
 class ShowSecurityGroupRule(common.NetworkAndComputeShowOne):
@@ -603,16 +575,19 @@ class ShowSecurityGroupRule(common.NetworkAndComputeShowOne):
         parser.add_argument(
             'rule',
             metavar="<rule>",
-            help=_("Security group rule to display (ID only)")
+            help=_("Security group rule to display (ID only)"),
         )
         return parser
 
     def take_action_network(self, client, parsed_args):
-        obj = client.find_security_group_rule(parsed_args.rule,
-                                              ignore_missing=False)
+        obj = client.find_security_group_rule(
+            parsed_args.rule, ignore_missing=False
+        )
         # necessary for old rules that have None in this field
         if not obj['remote_ip_prefix']:
-            obj['remote_ip_prefix'] = _format_remote_ip_prefix(obj)
+            obj['remote_ip_prefix'] = network_utils.format_remote_ip_prefix(
+                obj
+            )
         display_columns, columns = _get_columns(obj)
         data = utils.get_item_properties(obj, columns)
         return (display_columns, data)
@@ -624,7 +599,7 @@ class ShowSecurityGroupRule(common.NetworkAndComputeShowOne):
         # the requested rule.
         obj = None
         security_group_rules = []
-        for security_group in client.api.security_group_list():
+        for security_group in compute_v2.list_security_groups(client):
             security_group_rules.extend(security_group['rules'])
         for security_group_rule in security_group_rules:
             if parsed_args.rule == str(security_group_rule.get('id')):
@@ -632,9 +607,11 @@ class ShowSecurityGroupRule(common.NetworkAndComputeShowOne):
                 break
 
         if obj is None:
-            msg = _("Could not find security group rule "
-                    "with ID '%s'") % parsed_args.rule
+            msg = (
+                _("Could not find security group rule " "with ID '%s'")
+                % parsed_args.rule
+            )
             raise exceptions.CommandError(msg)
 
         # NOTE(rtheis): Format security group rule
-        return _format_security_group_rule_show(obj)
+        return network_utils.format_security_group_rule_show(obj)
