@@ -9,13 +9,12 @@
 #   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #   License for the specific language governing permissions and limitations
 #   under the License.
-#
 
 from unittest import mock
-from unittest.mock import call
 
 from osc_lib import exceptions
 
+from openstackclient.api import compute_v2
 from openstackclient.network import utils as network_utils
 from openstackclient.network.v2 import security_group_rule
 from openstackclient.tests.unit.compute.v2 import fakes as compute_fakes
@@ -23,20 +22,8 @@ from openstackclient.tests.unit.identity.v3 import fakes as identity_fakes
 from openstackclient.tests.unit import utils as tests_utils
 
 
-class TestSecurityGroupRuleCompute(compute_fakes.TestComputev2):
-
-    def setUp(self):
-        super(TestSecurityGroupRuleCompute, self).setUp()
-
-        # Get a shortcut to the network client
-        self.compute = self.app.client_manager.compute
-
-
-@mock.patch(
-    'openstackclient.api.compute_v2.APIv2.security_group_rule_create'
-)
-class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
-
+@mock.patch.object(compute_v2, 'create_security_group_rule')
+class TestCreateSecurityGroupRuleCompute(compute_fakes.TestComputev2):
     project = identity_fakes.FakeProject.create_one_project()
     domain = identity_fakes.FakeDomain.create_one_domain()
 
@@ -44,24 +31,26 @@ class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
     _security_group_rule = None
 
     # The security group that will contain the rule created.
-    _security_group = \
-        compute_fakes.FakeSecurityGroup.create_one_security_group()
+    _security_group = compute_fakes.create_one_security_group()
 
     def _setup_security_group_rule(self, attrs=None):
-        self._security_group_rule = \
-            compute_fakes.FakeSecurityGroupRule.create_one_security_group_rule(
-                attrs)
-        expected_columns, expected_data = \
-            security_group_rule._format_security_group_rule_show(
-                self._security_group_rule)
+        self._security_group_rule = (
+            compute_fakes.create_one_security_group_rule(attrs)
+        )
+        (
+            expected_columns,
+            expected_data,
+        ) = network_utils.format_security_group_rule_show(
+            self._security_group_rule
+        )
         return expected_columns, expected_data
 
     def setUp(self):
-        super(TestCreateSecurityGroupRuleCompute, self).setUp()
+        super().setUp()
 
         self.app.client_manager.network_endpoint_enabled = False
 
-        self.compute.api.security_group_find = mock.Mock(
+        compute_v2.find_security_group = mock.Mock(
             return_value=self._security_group,
         )
 
@@ -69,69 +58,108 @@ class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         self.cmd = security_group_rule.CreateSecurityGroupRule(self.app, None)
 
     def test_security_group_rule_create_no_options(self, sgr_mock):
-        self.assertRaises(tests_utils.ParserException,
-                          self.check_parser, self.cmd, [], [])
+        self.assertRaises(
+            tests_utils.ParserException, self.check_parser, self.cmd, [], []
+        )
 
     def test_security_group_rule_create_all_remote_options(self, sgr_mock):
         arglist = [
-            '--remote-ip', '10.10.0.0/24',
-            '--remote-group', self._security_group['id'],
+            '--remote-ip',
+            '10.10.0.0/24',
+            '--remote-group',
+            self._security_group['id'],
             self._security_group['id'],
         ]
-        self.assertRaises(tests_utils.ParserException,
-                          self.check_parser, self.cmd, arglist, [])
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            [],
+        )
 
     def test_security_group_rule_create_bad_protocol(self, sgr_mock):
         arglist = [
-            '--protocol', 'foo',
+            '--protocol',
+            'foo',
             self._security_group['id'],
         ]
-        self.assertRaises(tests_utils.ParserException,
-                          self.check_parser, self.cmd, arglist, [])
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            [],
+        )
 
     def test_security_group_rule_create_all_protocol_options(self, sgr_mock):
         arglist = [
-            '--protocol', 'tcp',
-            '--proto', 'tcp',
+            '--protocol',
+            'tcp',
+            '--proto',
+            'tcp',
             self._security_group['id'],
         ]
-        self.assertRaises(tests_utils.ParserException,
-                          self.check_parser, self.cmd, arglist, [])
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            [],
+        )
 
     def test_security_group_rule_create_network_options(self, sgr_mock):
         arglist = [
             '--ingress',
-            '--ethertype', 'IPv4',
-            '--icmp-type', '3',
-            '--icmp-code', '11',
-            '--project', self.project.name,
-            '--project-domain', self.domain.name,
+            '--ethertype',
+            'IPv4',
+            '--icmp-type',
+            '3',
+            '--icmp-code',
+            '11',
+            '--project',
+            self.project.name,
+            '--project-domain',
+            self.domain.name,
             self._security_group['id'],
         ]
-        self.assertRaises(tests_utils.ParserException,
-                          self.check_parser, self.cmd, arglist, [])
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            [],
+        )
 
     def test_security_group_rule_create_default_rule(self, sgr_mock):
         expected_columns, expected_data = self._setup_security_group_rule()
         sgr_mock.return_value = self._security_group_rule
-        dst_port = str(self._security_group_rule['from_port']) + ':' + \
-            str(self._security_group_rule['to_port'])
+        dst_port = (
+            str(self._security_group_rule['from_port'])
+            + ':'
+            + str(self._security_group_rule['to_port'])
+        )
         arglist = [
-            '--dst-port', dst_port,
+            '--dst-port',
+            dst_port,
             self._security_group['id'],
         ]
         verifylist = [
-            ('dst_port', (self._security_group_rule['from_port'],
-                          self._security_group_rule['to_port'])),
+            (
+                'dst_port',
+                (
+                    self._security_group_rule['from_port'],
+                    self._security_group_rule['to_port'],
+                ),
+            ),
             ('group', self._security_group['id']),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        # TODO(dtroyer): save this for the security group rule changes
-        # self.compute.api.security_group_rule_create.assert_called_once_with(
         sgr_mock.assert_called_once_with(
+            self.compute_sdk_client,
             security_group_id=self._security_group['id'],
             ip_protocol=self._security_group_rule['ip_protocol'],
             from_port=self._security_group_rule['from_port'],
@@ -143,20 +171,29 @@ class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         self.assertEqual(expected_data, data)
 
     def test_security_group_rule_create_remote_group(self, sgr_mock):
-        expected_columns, expected_data = self._setup_security_group_rule({
-            'from_port': 22,
-            'to_port': 22,
-            'group': {'name': self._security_group['name']},
-        })
+        expected_columns, expected_data = self._setup_security_group_rule(
+            {
+                'from_port': 22,
+                'to_port': 22,
+                'group': {'name': self._security_group['name']},
+            }
+        )
         sgr_mock.return_value = self._security_group_rule
         arglist = [
-            '--dst-port', str(self._security_group_rule['from_port']),
-            '--remote-group', self._security_group['name'],
+            '--dst-port',
+            str(self._security_group_rule['from_port']),
+            '--remote-group',
+            self._security_group['name'],
             self._security_group['id'],
         ]
         verifylist = [
-            ('dst_port', (self._security_group_rule['from_port'],
-                          self._security_group_rule['to_port'])),
+            (
+                'dst_port',
+                (
+                    self._security_group_rule['from_port'],
+                    self._security_group_rule['to_port'],
+                ),
+            ),
             ('remote_group', self._security_group['name']),
             ('group', self._security_group['id']),
         ]
@@ -164,9 +201,8 @@ class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        # TODO(dtroyer): save this for the security group rule changes
-        # self.compute.api.security_group_rule_create.assert_called_once_with(
         sgr_mock.assert_called_once_with(
+            self.compute_sdk_client,
             security_group_id=self._security_group['id'],
             ip_protocol=self._security_group_rule['ip_protocol'],
             from_port=self._security_group_rule['from_port'],
@@ -178,16 +214,20 @@ class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         self.assertEqual(expected_data, data)
 
     def test_security_group_rule_create_remote_ip(self, sgr_mock):
-        expected_columns, expected_data = self._setup_security_group_rule({
-            'ip_protocol': 'icmp',
-            'from_port': -1,
-            'to_port': -1,
-            'ip_range': {'cidr': '10.0.2.0/24'},
-        })
+        expected_columns, expected_data = self._setup_security_group_rule(
+            {
+                'ip_protocol': 'icmp',
+                'from_port': -1,
+                'to_port': -1,
+                'ip_range': {'cidr': '10.0.2.0/24'},
+            }
+        )
         sgr_mock.return_value = self._security_group_rule
         arglist = [
-            '--protocol', self._security_group_rule['ip_protocol'],
-            '--remote-ip', self._security_group_rule['ip_range']['cidr'],
+            '--protocol',
+            self._security_group_rule['ip_protocol'],
+            '--remote-ip',
+            self._security_group_rule['ip_range']['cidr'],
             self._security_group['id'],
         ]
         verifylist = [
@@ -199,9 +239,8 @@ class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        # TODO(dtroyer): save this for the security group rule changes
-        # self.compute.api.security_group_rule_create.assert_called_once_with(
         sgr_mock.assert_called_once_with(
+            self.compute_sdk_client,
             security_group_id=self._security_group['id'],
             ip_protocol=self._security_group_rule['ip_protocol'],
             from_port=self._security_group_rule['from_port'],
@@ -213,16 +252,20 @@ class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         self.assertEqual(expected_data, data)
 
     def test_security_group_rule_create_proto_option(self, sgr_mock):
-        expected_columns, expected_data = self._setup_security_group_rule({
-            'ip_protocol': 'icmp',
-            'from_port': -1,
-            'to_port': -1,
-            'ip_range': {'cidr': '10.0.2.0/24'},
-        })
+        expected_columns, expected_data = self._setup_security_group_rule(
+            {
+                'ip_protocol': 'icmp',
+                'from_port': -1,
+                'to_port': -1,
+                'ip_range': {'cidr': '10.0.2.0/24'},
+            }
+        )
         sgr_mock.return_value = self._security_group_rule
         arglist = [
-            '--proto', self._security_group_rule['ip_protocol'],
-            '--remote-ip', self._security_group_rule['ip_range']['cidr'],
+            '--proto',
+            self._security_group_rule['ip_protocol'],
+            '--remote-ip',
+            self._security_group_rule['ip_range']['cidr'],
             self._security_group['id'],
         ]
         verifylist = [
@@ -235,9 +278,8 @@ class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        # TODO(dtroyer): save this for the security group rule changes
-        # self.compute.api.security_group_rule_create.assert_called_once_with(
         sgr_mock.assert_called_once_with(
+            self.compute_sdk_client,
             security_group_id=self._security_group['id'],
             ip_protocol=self._security_group_rule['ip_protocol'],
             from_port=self._security_group_rule['from_port'],
@@ -249,18 +291,13 @@ class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         self.assertEqual(expected_data, data)
 
 
-@mock.patch(
-    'openstackclient.api.compute_v2.APIv2.security_group_rule_delete'
-)
-class TestDeleteSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
-
+@mock.patch.object(compute_v2, 'delete_security_group_rule')
+class TestDeleteSecurityGroupRuleCompute(compute_fakes.TestComputev2):
     # The security group rule to be deleted.
-    _security_group_rules = \
-        compute_fakes.FakeSecurityGroupRule.create_security_group_rules(
-            count=2)
+    _security_group_rules = compute_fakes.create_security_group_rules(count=2)
 
     def setUp(self):
-        super(TestDeleteSecurityGroupRuleCompute, self).setUp()
+        super().setUp()
 
         self.app.client_manager.network_endpoint_enabled = False
 
@@ -279,26 +316,34 @@ class TestDeleteSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         result = self.cmd.take_action(parsed_args)
 
         sgr_mock.assert_called_once_with(
-            self._security_group_rules[0]['id'])
+            self.compute_sdk_client, self._security_group_rules[0]['id']
+        )
         self.assertIsNone(result)
 
     def test_security_group_rule_delete_multi(self, sgr_mock):
-        arglist = []
-        verifylist = []
-
-        for s in self._security_group_rules:
-            arglist.append(s['id'])
+        arglist = [
+            self._security_group_rules[0]['id'],
+            self._security_group_rules[1]['id'],
+        ]
         verifylist = [
             ('rule', arglist),
         ]
-        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         result = self.cmd.take_action(parsed_args)
 
-        calls = []
-        for s in self._security_group_rules:
-            calls.append(call(s['id']))
-        sgr_mock.assert_has_calls(calls)
+        sgr_mock.assert_has_calls(
+            [
+                mock.call(
+                    self.compute_sdk_client,
+                    self._security_group_rules[0]['id'],
+                ),
+                mock.call(
+                    self.compute_sdk_client,
+                    self._security_group_rules[1]['id'],
+                ),
+            ]
+        )
         self.assertIsNone(result)
 
     def test_security_group_rule_delete_multi_with_exception(self, sgr_mock):
@@ -307,13 +352,11 @@ class TestDeleteSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
             'unexist_rule',
         ]
         verifylist = [
-            ('rule',
-             [self._security_group_rules[0]['id'], 'unexist_rule']),
+            ('rule', arglist),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        find_mock_result = [None, exceptions.CommandError]
-        sgr_mock.side_effect = find_mock_result
+        sgr_mock.side_effect = [None, exceptions.NotFound('foo')]
 
         try:
             self.cmd.take_action(parsed_args)
@@ -321,36 +364,41 @@ class TestDeleteSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         except exceptions.CommandError as e:
             self.assertEqual('1 of 2 rules failed to delete.', str(e))
 
-        sgr_mock.assert_any_call(
-            self._security_group_rules[0]['id'])
-        sgr_mock.assert_any_call(
-            'unexist_rule')
+        sgr_mock.assert_has_calls(
+            [
+                mock.call(
+                    self.compute_sdk_client,
+                    self._security_group_rules[0]['id'],
+                ),
+                mock.call(self.compute_sdk_client, 'unexist_rule'),
+            ]
+        )
 
 
-class TestListSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
-
+class TestListSecurityGroupRuleCompute(compute_fakes.TestComputev2):
     # The security group to hold the rules.
-    _security_group = \
-        compute_fakes.FakeSecurityGroup.create_one_security_group()
+    _security_group = compute_fakes.create_one_security_group()
 
     # The security group rule to be listed.
-    _security_group_rule_tcp = \
-        compute_fakes.FakeSecurityGroupRule.create_one_security_group_rule({
+    _security_group_rule_tcp = compute_fakes.create_one_security_group_rule(
+        {
             'ip_protocol': 'tcp',
             'ethertype': 'IPv4',
             'from_port': 80,
             'to_port': 80,
             'group': {'name': _security_group['name']},
-        })
-    _security_group_rule_icmp = \
-        compute_fakes.FakeSecurityGroupRule.create_one_security_group_rule({
+        }
+    )
+    _security_group_rule_icmp = compute_fakes.create_one_security_group_rule(
+        {
             'ip_protocol': 'icmp',
             'ethertype': 'IPv4',
             'from_port': -1,
             'to_port': -1,
             'ip_range': {'cidr': '10.0.2.0/24'},
             'group': {'name': _security_group['name']},
-        })
+        }
+    )
     _security_group['rules'] = [
         _security_group_rule_tcp,
         _security_group_rule_icmp,
@@ -362,10 +410,12 @@ class TestListSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         'Ethertype',
         'IP Range',
         'Port Range',
+        'Direction',
         'Remote Security Group',
     )
-    expected_columns_no_group = \
-        expected_columns_with_group + ('Security Group',)
+    expected_columns_no_group = expected_columns_with_group + (
+        'Security Group',
+    )
 
     expected_data_with_group = []
     expected_data_no_group = []
@@ -381,20 +431,21 @@ class TestListSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
             rule['port_range'],
             rule['remote_security_group'],
         )
-        expected_rule_no_group = expected_rule_with_group + \
-            (_security_group_rule['parent_group_id'],)
+        expected_rule_no_group = expected_rule_with_group + (
+            _security_group_rule['parent_group_id'],
+        )
         expected_data_with_group.append(expected_rule_with_group)
         expected_data_no_group.append(expected_rule_no_group)
 
     def setUp(self):
-        super(TestListSecurityGroupRuleCompute, self).setUp()
+        super().setUp()
 
         self.app.client_manager.network_endpoint_enabled = False
 
-        self.compute.api.security_group_find = mock.Mock(
+        compute_v2.find_security_group = mock.Mock(
             return_value=self._security_group,
         )
-        self.compute.api.security_group_list = mock.Mock(
+        compute_v2.list_security_groups = mock.Mock(
             return_value=[self._security_group],
         )
 
@@ -405,8 +456,8 @@ class TestListSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         parsed_args = self.check_parser(self.cmd, [], [])
 
         columns, data = self.cmd.take_action(parsed_args)
-        self.compute.api.security_group_list.assert_called_once_with(
-            search_opts={'all_tenants': False}
+        compute_v2.list_security_groups.assert_called_once_with(
+            self.compute_sdk_client, all_projects=False
         )
         self.assertEqual(self.expected_columns_no_group, columns)
         self.assertEqual(self.expected_data_no_group, list(data))
@@ -421,8 +472,8 @@ class TestListSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        self.compute.api.security_group_find.assert_called_once_with(
-            self._security_group['id']
+        compute_v2.find_security_group.assert_called_once_with(
+            self.compute_sdk_client, self._security_group['id']
         )
         self.assertEqual(self.expected_columns_with_group, columns)
         self.assertEqual(self.expected_data_with_group, list(data))
@@ -437,8 +488,8 @@ class TestListSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        self.compute.api.security_group_list.assert_called_once_with(
-            search_opts={'all_tenants': True}
+        compute_v2.list_security_groups.assert_called_once_with(
+            self.compute_sdk_client, all_projects=True
         )
         self.assertEqual(self.expected_columns_no_group, columns)
         self.assertEqual(self.expected_data_no_group, list(data))
@@ -453,32 +504,30 @@ class TestListSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        self.compute.api.security_group_list.assert_called_once_with(
-            search_opts={'all_tenants': False}
+        compute_v2.list_security_groups.assert_called_once_with(
+            self.compute_sdk_client, all_projects=False
         )
         self.assertEqual(self.expected_columns_no_group, columns)
         self.assertEqual(self.expected_data_no_group, list(data))
 
 
-class TestShowSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
-
+class TestShowSecurityGroupRuleCompute(compute_fakes.TestComputev2):
     # The security group rule to be shown.
-    _security_group_rule = \
-        compute_fakes.FakeSecurityGroupRule.create_one_security_group_rule()
+    _security_group_rule = compute_fakes.create_one_security_group_rule()
 
-    columns, data = \
-        security_group_rule._format_security_group_rule_show(
-            _security_group_rule)
+    columns, data = network_utils.format_security_group_rule_show(
+        _security_group_rule
+    )
 
     def setUp(self):
-        super(TestShowSecurityGroupRuleCompute, self).setUp()
+        super().setUp()
 
         self.app.client_manager.network_endpoint_enabled = False
 
         # Build a security group fake customized for this test.
         security_group_rules = [self._security_group_rule]
         security_group = {'rules': security_group_rules}
-        self.compute.api.security_group_list = mock.Mock(
+        compute_v2.list_security_groups = mock.Mock(
             return_value=[security_group],
         )
 
@@ -486,8 +535,9 @@ class TestShowSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         self.cmd = security_group_rule.ShowSecurityGroupRule(self.app, None)
 
     def test_security_group_rule_show_no_options(self):
-        self.assertRaises(tests_utils.ParserException,
-                          self.check_parser, self.cmd, [], [])
+        self.assertRaises(
+            tests_utils.ParserException, self.check_parser, self.cmd, [], []
+        )
 
     def test_security_group_rule_show_all_options(self):
         arglist = [
@@ -500,6 +550,8 @@ class TestShowSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.compute.api.security_group_list.assert_called_once_with()
+        compute_v2.list_security_groups.assert_called_once_with(
+            self.compute_sdk_client
+        )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
